@@ -11,7 +11,7 @@ from git_code_debt.metrics.common import FILE_TYPE_MAP
 class LinesOfCodeParser(DiffParserBase):
     """Counts lines of code in a repository, overall and by file types."""
 
-    def get_metrics_from_stat(self, file_diff_stats):
+    def get_metrics_from_stat(self, _, file_diff_stats):
         total_lines = 0
         lines_by_file_type = collections.defaultdict(int)
 
@@ -30,15 +30,15 @@ class LinesOfCodeParser(DiffParserBase):
 
         # Yield overall metric and one per type of expected mapping types
         yield Metric('TotalLinesOfCode', total_lines)
-        for file_type in set(FILE_TYPE_MAP.values()) | set(['unknown']):
+        for file_type in set(FILE_TYPE_MAP.values()) | {'unknown'}:
             lines_changed = lines_by_file_type.get(file_type, 0)
             yield Metric(
-                'TotalLinesOfCode_{0}'.format(file_type),
+                'TotalLinesOfCode_{}'.format(file_type),
                 lines_changed,
             )
 
     def get_possible_metric_ids(self):
         return ['TotalLinesOfCode'] + [
-            'TotalLinesOfCode_{0}'.format(file_type)
-            for file_type in set(FILE_TYPE_MAP.values()) | set(['unknown'])
+            'TotalLinesOfCode_{}'.format(file_type)
+            for file_type in set(FILE_TYPE_MAP.values()) | {'unknown'}
         ]
