@@ -1,4 +1,3 @@
-# pylint:disable=star-args
 from __future__ import absolute_import
 from __future__ import unicode_literals
 
@@ -12,7 +11,8 @@ from git_code_debt.util.iter import chunk_iter
 from git_code_debt.util.subprocess import cmd_output
 
 
-Commit = collections.namedtuple('Commit', ['sha', 'date'])
+Commit = collections.namedtuple('Commit', ('sha', 'date'))
+Commit.blank = Commit('0' * 40, 0)
 
 COMMIT_FORMAT = '--format=%H%n%ct'
 
@@ -61,7 +61,7 @@ class RepoParser(object):
         cmd = ['git', 'log', '--first-parent', '--reverse', COMMIT_FORMAT]
         if since_sha:
             commits = [self.get_commit(since_sha)]
-            cmd.append('{0}..HEAD'.format(since_sha))
+            cmd.append('{}..HEAD'.format(since_sha))
         else:
             commits = []
             cmd.append('HEAD')
@@ -83,6 +83,7 @@ class RepoParser(object):
     def get_commit_diff(self, previous_sha, sha):
         assert self.tempdir
         output = cmd_output(
-            'git', 'diff', previous_sha, sha, cwd=self.tempdir, encoding=None,
+            'git', 'diff', previous_sha, sha, '--no-renames',
+            cwd=self.tempdir, encoding=None,
         )
         return output
