@@ -78,10 +78,10 @@ def main(argv=None):  # pragma: no cover (starts a web server)
     args = parser.parse_args(argv)
 
     if not os.path.exists(args.database_path):
-        print('Not found: {0}'.format(args.database_path))
+        print('Not found: {}'.format(args.database_path))
         print(
             'Use git-code-debt-create-tables and git-code-debt-generate to '
-            'create a database.'
+            'create a database.',
         )
         return 1
 
@@ -95,7 +95,7 @@ def main(argv=None):  # pragma: no cover (starts a web server)
     if not args.debug:
         kwargs['processes'] = args.processes
 
-    app.run('0.0.0.0', **kwargs)  # pylint:disable=star-args
+    app.run('0.0.0.0', **kwargs)
 
 
 if __name__ == '__main__':
