@@ -2,14 +2,15 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 
 import io
+import json
 
 import flask
-import simplejson
 import yaml
 
 from git_code_debt.discovery import get_metric_parsers_from_args
 from git_code_debt.generate import get_metrics
 from git_code_debt.generate_config import GenerateOptions
+from git_code_debt.repo_parser import Commit
 from git_code_debt.server.metric_config import widget_metrics
 from git_code_debt.server.presentation.commit_delta import CommitDeltaPresenter
 from git_code_debt.server.presentation.delta import DeltaPresenter
@@ -35,7 +36,7 @@ def data():
     parsers = get_metric_parsers_from_args(
         metric_config.metric_package_names, skip_defaults=False,
     )
-    metrics = get_metrics(diff, parsers)
+    metrics = get_metrics(Commit.blank, diff, parsers)
     metrics = [
         metric for metric in metrics
         if metric.value and metric.name in metric_names
@@ -47,6 +48,6 @@ def data():
         )
         for metric in metrics
     ])
-    return simplejson.dumps({
-        'metrics': render_template('widget.mako', commit_deltas=commit_deltas)
+    return json.dumps({
+        'metrics': render_template('widget.mako', commit_deltas=commit_deltas),
     })
